@@ -100,7 +100,7 @@ class GoogleAlerts:
 
     NAME = "GoogleAlerts"
     LOG_LEVEL = logging.DEBUG
-    LOGIN_URL = 'https://accounts.google.com/ServiceLogin?nojavascript=1'
+    LOGIN_URL = 'https://accounts.google.com/signin'
     AUTH_URL = 'https://accounts.google.com/signin/challenge/sl/password'
     ALERTS_URL = 'https://www.google.com/alerts'
     TEST_URL = 'https://myaccount.google.com/?pli=1'
@@ -233,7 +233,7 @@ class GoogleAlerts:
                 if state != "":
                     self._state = state
                     self._log.debug("State value set: %s" % self._state)
-            except Exception, e:
+            except Exception as e:
                 raise StateParseFailure("Google has changed their core protocol and a new parser must be built. Please file a bug at https://github.com/9b/google-alerts/issues.")
         return self._state
 
@@ -243,10 +243,12 @@ class GoogleAlerts:
         region = options.get('region', 'US')
         language = options.get('language', 'en')
         imatch_type = {v: k for k, v in self.MONITOR_MATCH_TYPE.items()}
-        monitor_match = imatch_type[options.get('monitor_match', 'BEST')]
+        monitor_match = imatch_type[options.get('monitor_match', 'ALL')]
         ialert_freq = {v: k for k, v in self.ALERT_FREQ.items()}
         freq_option = options.get('alert_frequency', 'AT_MOST_ONCE_A_DAY')
         freq_option = ialert_freq[freq_option]
+        if 'alert_frequency' not in options:
+            options['alert_frequency'] = 'AT_MOST_ONCE_A_DAY'
         if options.get('exact', False):
             term = "\"%s\"" % term
 
@@ -330,7 +332,7 @@ class GoogleAlerts:
         if not self._state:
             raise InvalidState("State was not properly obtained from the app")
         self._process_state()
-        if not self._state[1]:
+        if not self._state[0]:
             self._log.info("No monitors have been created yet.")
             return list()
 
@@ -345,7 +347,6 @@ class GoogleAlerts:
                     continue
                 obj['language'] = monitor[1][2][2][0]
                 obj['region'] = monitor[1][2][2][1]
-                print(monitor[1][5][0])
                 obj['delivery'] = self.DELIVERY[monitor[1][5][0][0]]
                 obj['match_type'] = self.MONITOR_MATCH_TYPE[monitor[1][4]]
                 if obj['delivery'] == 'MAIL':
@@ -356,7 +357,7 @@ class GoogleAlerts:
                     url = "https://google.com/alerts/feeds/{uid}/{fid}"
                     obj['rss_link'] = url.format(uid=obj['user_id'], fid=rss_id)
                 monitors.append(obj)
-        except Exception, e:
+        except Exception as e:
             raise StateParseFailure("Observed state differs from parser. Please file a bug at https://github.com/9b/google-alerts/issues.")
         return monitors
 
